mm2

Struct mm2 

pub struct mm2(/* private fields */);

Implementations

Source

impl mm2

pub const fn try_new(inner: f32) -> Result<Self, NonFinite>

This is a helper method for creating this type. Take a look at the Unit trait for a more idiomatic way to create this type.

Note: This method is only const when using a nightly Rust compiler.

pub const fn new(inner: f32) -> Self

This is a helper method for creating this type. Take a look at the Unit trait for a more idiomatic way to create this type.

Note: This method is only const when using a nightly Rust compiler.

Panics

This method panics if the inner value is non-finite.

pub const fn raw_value(self) -> f32

Return the raw value.

Source

impl mm2

pub fn round(self) -> Self

Returns the nearest integer to self. Round half-way cases away from 0.0.

pub fn abs(self) -> Self

Returns the absolute value of self.

pub fn atan2(self, other: Self) -> f32

Computes the four quadrant arctangent of self and other in radians.

Source

impl mm2

pub fn sqrt(self) -> mm